################################################################################
#                                                                              #
# Copyright (c) 2020 VIA Technologies, Inc. All Rights Reserved.               #
#                                                                              #
# This PROPRIETARY SOFTWARE is the property of VIA Technologies, Inc.          #
# and may contain trade secrets and/or other confidential information of       #
# VIA Technologies, Inc. This file shall not be disclosed to any third         #
# party, in whole or in part, without prior written consent of VIA.            #
#                                                                              #
# THIS PROPRIETARY SOFTWARE AND ANY RELATED DOCUMENTATION ARE PROVIDED AS IS,  #
# WITH ALL FAULTS, AND WITHOUT WARRANTY OF ANY KIND EITHER EXPRESS OR IMPLIED, #
# AND VIA TECHNOLOGIES, INC. DISCLAIMS ALL EXPRESS OR IMPLIED                  #
# WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, QUIET       #
# ENJOYMENT OR NON-INFRINGEMENT.                                               #
#                                                                              #
################################################################################

from pixetto import Pixetto
import pixetto

pix = Pixetto()

# Windows
pix.open("COM3")   # com port id of Pixetto

# Linux
#pix.open("/dev/ttyACM0")   # com port id of Pixetto

print("open COM3 OK")

''' 
These APIs are used to configure Pixetto to a specific function.
You can use them to switch among functions.
Please note that only one function can be enabled at a time.
''' 
#pix.enable_color_detection(color=[pixetto.COLOR_RED, pixetto.COLOR_BLUE], maxdisp=1, minsize=1)
#pix.enable_colorcode_detection(color=[pixetto.COLOR_RED, pixetto.COLOR_BLUE], maxdisp=1, minsize=1)
#pix.enable_shape_detection(shape=[pixetto.SHAPE_RECTANGLE, pixetto.SHAPE_TRIANGLE], maxdisp=1, minsize=1)
#pix.enable_sphere_detection(color=[pixetto.COLOR_RED, pixetto.COLOR_BLUE], maxdisp=1, minsize=1)
#pix.enable_template(maxdisp=1)
#pix.enable_keypoint(hamming_dist=50, matched=5, maxdisp=1)
#pix.enable_neural_network(roi_type=pixetto.ROI_CENTRAL, maxdisp=1)
#pix.enable_apriltag(maxdisp=1)
#pix.enable_face_detection(maxdisp=1)
#pix.enable_traffic_sign_detection(maxdisp=1)
#pix.enable_handwritten_digits_detection(maxdisp=1)
#pix.enable_handwritten_letters_detection(maxdisp=1)
#pix.enable_remote_computing(host="mls.pixetto.ai", target="/PixServerYolov3/", port=80, maxdisp=1)
#pix.enable_lanes_detection(black_lanes=False)
#pix.enable_digits_operation_detection(maxdisp=1)
#pix.enable_simple_classifier(roi_type=pixetto.ROI_CENTRAL, maxdisp=1)
#pix.enable_voice_commands()

while True:
    if pix.is_detected() == True:
        print(pix.get_raw_data())
        fid, num, objs = pix.get_data_list()
        print('[funcID, num] = [{},{}]'.format(fid, num))
        
        if (fid == pixetto.FUNC_SHAPE_DETECTION or
            fid == pixetto.FUNC_TRAFFIC_SIGN_DETECTION or 
            fid == pixetto.FUNC_HANDWRITTEN_DIGITS_DETECTION or 
            fid == pixetto.FUNC_HANDWRITTEN_LETTERS_DETECTION):
            for i in range(num):
                print(' [{}] - type:{} label:"{}" x:{}, y:{}, w:{}, h:{}'.format(i+1, objs[i]['type'], objs[i]['label'],
                    objs[i]['x'], objs[i]['y'], objs[i]['w'], objs[i]['h']))
            print()
            
        if (fid == pixetto.FUNC_COLOR_CODE_DETECTION or 
		    fid == pixetto.FUNC_SPHERE_DETECTION or
		    fid == pixetto.FUNC_TEMPLATE_MATCHING or
		    fid == pixetto.FUNC_KEYPOINTS or
		    fid == pixetto.FUNC_NEURAL_NETWORK or
		    fid == pixetto.FUNC_FACE_DETECTION or
		    fid == pixetto.FUNC_SIMPLE_CLASSIFIER):
            for i in range(num):
                print(' [{}] - type:{} x:{}, y:{}, w:{}, h:{}'.format(i+1, objs[i]['type'], 
                    objs[i]['x'], objs[i]['y'], objs[i]['w'], objs[i]['h']))
            print()

        # Refer to json fields you actually defined.
        # Here is the example for default remote computing "Yolov4".
        if fid == pixetto.FUNC_REMOTE_COMPUTING:
            for i in range(num):
                print(' [{}] - type:{} label:"{}" x:{}, y:{}, w:{}, h:{}'.format(i+1, objs[i]['type'], objs[i]['label'],
                    objs[i]['x'], objs[i]['y'], objs[i]['w'], objs[i]['h']))
            print()

        if fid == pixetto.FUNC_DIGITSOP_DETECTION:
            for i in range(num):
                print(' [{}] - equation:{} answer:{}'.format(i+1, objs[i]['label'], objs[i]['type']))
                print('      - x:{}, y:{}, w:{}, h:{}'.format(objs[i]['x'], objs[i]['y'], objs[i]['w'], objs[i]['h']))
            print()

        if fid == pixetto.FUNC_APRILTAG:
            for i in range(num):
                print(' [{}] - type:{}, x:{}, y:{}, w:{}, h:{}'.format(i+1, objs[i]['type'], objs[i]['x'], objs[i]['y'], objs[i]['w'], objs[i]['h']))
                print(' - center:({},{}) (posx, posy, posz):({},{},{}) (rotx, roty, rotz):({},{},{})'.format(
                    objs[i]['cx'], objs[i]['cy'], 
				    objs[i]['posx'], objs[i]['posy'], objs[i]['posz'], 
				    objs[i]['rotx'], objs[i]['roty'], objs[i]['rotz']))
            print()

        if fid == pixetto.FUNC_LANES_DETECTION:                                                                                                 
            print(' - center:({},{})  L1:({},{}) L2:({},{}) R1:({},{}) R2:({},{})'.format(
                objs[0]['x'], objs[0]['y'], 
	    	    objs[1]['x'], objs[1]['y'], objs[2]['x'], objs[2]['y'],
				objs[3]['x'], objs[3]['y'], objs[4]['x'], objs[4]['y']))
            print()
            
        if fid == pixetto.FUNC_VOICE_COMMANDS:
            print(' - voice commands:{}'.format(objs[0]['type']))
            print()
        
pix.close()
